register_metrics_into

Function register_metrics_into 

pub(crate) fn register_metrics_into(
    registry: &MetricsRegistry,
    disk_root: Option<PathBuf>,
) -> UsageMetrics
Register the resource usage sampler.

disk_root is a directory on the filesystem whose usage should be tracked, or None if this process does not use disk.